
__version__ = '0.0.5'

__title__ = 'repovisor'

__summary__ = 'A tool for managing many repositories and creating daily reports'

__uri__ = 'https://github.com/gjcooper/repovisor'

__license__ = 'BSD'

__author__ = 'Gavin Cooper'

__email__ = 'gjcooper@gmail.com'



from .repostate import GitRepoState
from git.exc import InvalidGitRepositoryError
from colorama import Fore, Style, init
import os

init()


def reposearch(*folders):
    for folder in folders:
        for dir, subdirs, files in os.walk(folder):
            try:
                yield GitRepoState(dir)
                subdirs[:] = []
                continue
            except InvalidGitRepositoryError:
                pass


def ahead_behind(ref):
    if ref['ahead']:
        glyph = Fore.RED + '+' + str(ref['ahead']) + Style.RESET_ALL
    else:
        glyph = '-'
    glyph += '/'
    if ref['behind']:
        glyph += Fore.RED + '-' + str(ref['behind']) + Style.RESET_ALL
    else:
        glyph += '-'
    return glyph


def branch_representation(branch):
    refview = '  Name: {:10.10} Upstream: '.format(branch['name'])
    if branch['upstream']:
        refview += '{!s:17.17} Status: {!s}'.format(branch['upstream'],
                                                    ahead_behind(branch))
    else:
        refview += Fore.YELLOW + 'None' + Style.RESET_ALL
    return refview


def state_representation(repo):
    """Print the state for a repository"""
    loc = 'Location: ' + repo.path
    state = repo.state
    mod = 'Modified: '
    if state['dirty']:
        mod += Fore.RED + 'Yes' + Style.RESET_ALL
    else:
        mod += Fore.GREEN + 'No' + Style.RESET_ALL
    untracked = 'Untracked: ' + Fore.YELLOW
    untracked += str(state['untracked']) + Style.RESET_ALL
    refs = 'Branches: \n'
    refs += '\n'.join([branch_representation(b) for b in state['refcheck']])
    return '\n'.join([loc, mod, untracked, refs])


def print_all(*repos):
    """Print all repo current state to terminal"""
    for repo in repos:
        print('‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾‾')
        print(state_representation(repo))
        print('________________________________________')



from repovisor import repovisor as rv
import sys
import argparse

def main():
    parser = argparse.ArgumentParser(description='Manage multiple repos')
    parser.add_argument('--search', '-s')
    parser.add_argument('--no_output', action='store_true')

    args = parser.parse_args()

    repos = []
    if args.search:
        repos += list(rv.reposearch(args.search))

    if not args.no_output:
        rv.print_all(*repos)
